mailr14517 - in /1.3/test_suite/unit_tests/_prompt: test_molmol.py test_pymol.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on August 29, 2011 - 16:19:
Author: bugman
Date: Mon Aug 29 16:19:17 2011
New Revision: 14517

URL: http://svn.gna.org/viewcvs/relax?rev=14517&view=rev
Log:
Fixes to the unit tests for the PyMOL and Molmol macro user function 
renamings.


Modified:
    1.3/test_suite/unit_tests/_prompt/test_molmol.py
    1.3/test_suite/unit_tests/_prompt/test_pymol.py

Modified: 1.3/test_suite/unit_tests/_prompt/test_molmol.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/test_suite/unit_tests/_prompt/test_molmol.py?rev=14517&r1=14516&r2=14517&view=diff
==============================================================================
--- 1.3/test_suite/unit_tests/_prompt/test_molmol.py (original)
+++ 1.3/test_suite/unit_tests/_prompt/test_molmol.py Mon Aug 29 16:19:17 2011
@@ -38,8 +38,8 @@
     molmol_fns = Molmol()
 
 
-    def test_macro_exec_argfail_data_type(self):
-        """The data_type arg test of the molmol.macro_exec() user 
function."""
+    def test_macro_apply_argfail_data_type(self):
+        """The data_type arg test of the molmol.macro_apply() user 
function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -48,11 +48,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxStrError, self.molmol_fns.macro_exec, 
data_type=data[1])
+            self.assertRaises(RelaxStrError, self.molmol_fns.macro_apply, 
data_type=data[1])
 
 
-    def test_macro_exec_argfail_style(self):
-        """The style arg test of the molmol.macro_exec() user function."""
+    def test_macro_apply_argfail_style(self):
+        """The style arg test of the molmol.macro_apply() user function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -61,11 +61,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxStrError, self.molmol_fns.macro_exec, 
data_type='a', style=data[1])
+            self.assertRaises(RelaxStrError, self.molmol_fns.macro_apply, 
data_type='a', style=data[1])
 
 
-    def test_macro_exec_argfail_colour_start(self):
-        """The colour_start arg test of the molmol.macro_exec() user 
function."""
+    def test_macro_apply_argfail_colour_start(self):
+        """The colour_start arg test of the molmol.macro_apply() user 
function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -74,11 +74,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxNoneStrListNumError, 
self.molmol_fns.macro_exec, data_type='a', style='x', colour_start=data[1])
+            self.assertRaises(RelaxNoneStrListNumError, 
self.molmol_fns.macro_apply, data_type='a', style='x', colour_start=data[1])
 
 
-    def test_macro_exec_argfail_colour_end(self):
-        """The colour_end arg test of the molmol.macro_exec() user 
function."""
+    def test_macro_apply_argfail_colour_end(self):
+        """The colour_end arg test of the molmol.macro_apply() user 
function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -87,11 +87,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxNoneStrListNumError, 
self.molmol_fns.macro_exec, data_type='a', style='x', colour_end=data[1])
+            self.assertRaises(RelaxNoneStrListNumError, 
self.molmol_fns.macro_apply, data_type='a', style='x', colour_end=data[1])
 
 
-    def test_macro_exec_argfail_colour_list(self):
-        """The colour_list arg test of the molmol.macro_exec() user 
function."""
+    def test_macro_apply_argfail_colour_list(self):
+        """The colour_list arg test of the molmol.macro_apply() user 
function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -100,4 +100,4 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxNoneStrError, self.molmol_fns.macro_exec, 
data_type='a', style='x', colour_list=data[1])
+            self.assertRaises(RelaxNoneStrError, 
self.molmol_fns.macro_apply, data_type='a', style='x', colour_list=data[1])

Modified: 1.3/test_suite/unit_tests/_prompt/test_pymol.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/test_suite/unit_tests/_prompt/test_pymol.py?rev=14517&r1=14516&r2=14517&view=diff
==============================================================================
--- 1.3/test_suite/unit_tests/_prompt/test_pymol.py (original)
+++ 1.3/test_suite/unit_tests/_prompt/test_pymol.py Mon Aug 29 16:19:17 2011
@@ -38,8 +38,8 @@
     pymol_fns = Pymol()
 
 
-    def test_macro_exec_argfail_data_type(self):
-        """The data_type arg test of the pymol.macro_exec() user function."""
+    def test_macro_apply_argfail_data_type(self):
+        """The data_type arg test of the pymol.macro_apply() user 
function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -48,11 +48,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxStrError, self.pymol_fns.macro_exec, 
data_type=data[1])
+            self.assertRaises(RelaxStrError, self.pymol_fns.macro_apply, 
data_type=data[1])
 
 
-    def test_macro_exec_argfail_style(self):
-        """The style arg test of the pymol.macro_exec() user function."""
+    def test_macro_apply_argfail_style(self):
+        """The style arg test of the pymol.macro_apply() user function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -61,11 +61,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxStrError, self.pymol_fns.macro_exec, 
data_type='a', style=data[1])
+            self.assertRaises(RelaxStrError, self.pymol_fns.macro_apply, 
data_type='a', style=data[1])
 
 
-    def test_macro_exec_argfail_colour_start(self):
-        """The colour_start arg test of the pymol.macro_exec() user 
function."""
+    def test_macro_apply_argfail_colour_start(self):
+        """The colour_start arg test of the pymol.macro_apply() user 
function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -74,11 +74,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxNoneStrListNumError, 
self.pymol_fns.macro_exec, data_type='a', style='x', colour_start=data[1])
+            self.assertRaises(RelaxNoneStrListNumError, 
self.pymol_fns.macro_apply, data_type='a', style='x', colour_start=data[1])
 
 
-    def test_macro_exec_argfail_colour_end(self):
-        """The colour_end arg test of the pymol.macro_exec() user 
function."""
+    def test_macro_apply_argfail_colour_end(self):
+        """The colour_end arg test of the pymol.macro_apply() user 
function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -87,11 +87,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxNoneStrListNumError, 
self.pymol_fns.macro_exec, data_type='a', style='x', colour_end=data[1])
+            self.assertRaises(RelaxNoneStrListNumError, 
self.pymol_fns.macro_apply, data_type='a', style='x', colour_end=data[1])
 
 
-    def test_macro_exec_argfail_colour_list(self):
-        """The colour_list arg test of the pymol.macro_exec() user 
function."""
+    def test_macro_apply_argfail_colour_list(self):
+        """The colour_list arg test of the pymol.macro_apply() user 
function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -100,4 +100,4 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxNoneStrError, self.pymol_fns.macro_exec, 
data_type='a', style='x', colour_list=data[1])
+            self.assertRaises(RelaxNoneStrError, self.pymol_fns.macro_apply, 
data_type='a', style='x', colour_list=data[1])




Related Messages


Powered by MHonArc, Updated Tue Aug 30 12:00:03 2011